summaryrefslogtreecommitdiff
path: root/libview/ev-transition-animation.c
diff options
context:
space:
mode:
Diffstat (limited to 'libview/ev-transition-animation.c')
-rw-r--r--libview/ev-transition-animation.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/libview/ev-transition-animation.c b/libview/ev-transition-animation.c
index a767019b..1e766af3 100644
--- a/libview/ev-transition-animation.c
+++ b/libview/ev-transition-animation.c
@@ -1,5 +1,5 @@
/* ev-transition-animation.c
* this file is part of evince, a mate document viewer
*
* Copyright (C) 2007 Carlos Garnacho <[email protected]>
*
@@ -591,7 +591,7 @@ ev_transition_animation_paint (EvTransitionAnimation *animation,
enum_value = g_enum_get_value (g_type_class_peek (EV_TYPE_TRANSITION_EFFECT_TYPE), type);
g_warning ("Unimplemented transition animation: '%s', "
- "please post a bug report in Evince bugzilla "
+ "please post a bug report in Atril bugzilla "
"(http://bugzilla.mate.org) with a testcase.",
enum_value->value_nick);
@@ -1,5 +1,5 @@
/* ev-transition-animation.c
- * this file is part of evince, a mate document viewer
+ * this file is part of atril, a mate document viewer
*
* Copyright (C) 2007 Carlos Garnacho <[email protected]>